<?php declare(strict_types=1);

namespace USKit\Base\Services;

use App\Interfaces\ThemeStartup;
use USKit\Base\Interfaces\ThemeServiceStartup;
use Infomaker\Everyware\NewsML\NewsMLTransformerManager;
use Infomaker\Everyware\NewsML\Parsers\ContentPartParser;
use Infomaker\Everyware\NewsML\Parsers\ElementParser;
use Infomaker\Everyware\NewsML\Parsers\HtmlEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\ImageGalleryParser;
use Infomaker\Everyware\NewsML\Parsers\ImageParser;
use Infomaker\Everyware\NewsML\Parsers\LinkObjectParser;
use Infomaker\Everyware\NewsML\Parsers\PdfParser;
use Infomaker\Everyware\NewsML\Parsers\ReviewParser;
use Infomaker\Everyware\NewsML\Parsers\SocialEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\TableParser;
use Infomaker\Everyware\NewsML\Parsers\TeaserParser;
use Infomaker\Everyware\NewsML\Parsers\YoutubeParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\ContactInfoParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PersonParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PolygonParser;

/**
 * Class ArticleParserService
 * @package USKit\Base\Services
 */
class NewsMLParserServiceStartup implements ThemeServiceStartup
{
    public function setup(): void
    {
        $elementParserForbidden = new ElementParser();
        $elementParserForbidden->addForbiddenTags(['ins']);
        NewsMLTransformerManager::registerElementParser($elementParserForbidden);

        $objectParsers = [
            SocialEmbedParser::OBJECT_TYPE => new SocialEmbedParser(),
            TeaserParser::OBJECT_TYPE => new TeaserParser(),
            ImageParser::OBJECT_TYPE => new ImageParser(),
            ImageGalleryParser::OBJECT_TYPE => new ImageGalleryParser(),
            TableParser::OBJECT_TYPE => new TableParser(),
            ContentPartParser::OBJECT_TYPE => new ContentPartParser($elementParserForbidden),
            ReviewParser::OBJECT_TYPE => new ReviewParser($elementParserForbidden),
            LinkObjectParser::OBJECT_TYPE => new LinkObjectParser(),
            HtmlEmbedParser::OBJECT_TYPE => new HtmlEmbedParser(),
            PdfParser::OBJECT_TYPE => new PdfParser(),
            YoutubeParser::OBJECT_TYPE => new YoutubeParser(),
            ContactInfoParser::OBJECT_TYPE => new ContactInfoParser(),
            PolygonParser::OBJECT_TYPE => new PolygonParser(),
            PersonParser::OBJECT_TYPE => new PersonParser(),
        ];

        foreach ($objectParsers as $type => $parser) {
            NewsMLTransformerManager::registerObjectParser($type, $parser);
        }
    }
}
